<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="am_ET">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>ክლິກ ກະຈາຍ ອິຄອນ
ຫຼື ພິມ ການສັ່ງສະເໜີອີກເທື່ອ ເພື່ອຢູ່ເທື່ອ ການບັນທຶກ</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>ບໍ່ຢູ່ເທື່ອ ການເຄື່ອນຍ້າຍ ກະຈາຍ ອິຄອນ ໃນຂະນະທີ່ບັນທຶກ</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>ການບັນທຶກຮູບ</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>ການບັນທຶກ</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Record</source>
        <translation>መቅረጫ</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>ການບັນທຶກຮູບ</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>ການບັນທຶກຈໍານວນ</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>ບັນທຶກບໍ່ສຳເລັດ. ພວກເຈົ້າສາມາດບັນທຶກມັນໃນເຊື່ອມຕໍ່ເຮືອນຂອງທ່ານ.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>መቅረጽ ጨርሷል</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>የተመረጠው-ቦታ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ማስቀመጫ</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>ተቀምጧል በ %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>መተው</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>ቁራጭ ሰሌዳ</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>ກຳລັງບັນທຶກໄຟລ໌ການບັນທຶກຈໍານວນ, ພວກເຈົ້າກະລຸນາລໍຖ້າ...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>ເນື່ອງຈາກການປະກອບຂະບວນການຖືກປິດໃນຂະນະທີ່ກຳລັງເຮັດ, ການບັນທຶກຈໍານວນຕ້ອງ
ຖືກຢູ່ເທື່ອ</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>ການບັນທຶກຮູບ</translation>
    </message>
    <message>
        <source>Screenshot failed.</source>
        <translation>ການບັນທຶກຮູບບໍ່ສຳເລັດ.</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>ການບັນທຶກສະແດງ</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>ບັນທຶກຮູບເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>deepin-screen-recorder</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>ເປີດເຊື່ອມຕໍ່</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>ການບັນທຶກຮູບສຳເລັດແລ້ວ ແລະ ສຳເນີມໄປຫຼັງຄອບ</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>መተው</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ማስቀመጫ</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>ບັນທຶກຮູບເຊື່ອີງ</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>ການບັນທຶກຮູບ</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>ບັນທຶກ</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>ການບັນທຶກຮູບ</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>ການບັນທຶກ</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>መመልከቻ</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>መቅረጽ ጨርሷል</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation> ተቀምጧል በ %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>መቅረጫ</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>ເປີດເຊື່ອມຕໍ່</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>ການບັນທຶກຈໍານວນຈະເລີ່ມຕົ້ນໃນ %1 ນັ້ນ</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>ໄດ້ຮັບການຊ່ວຍເຫັນ.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>ບໍ່ສາມາດເອົາການບັນທຶກສະແດງຕ່ໍາໄດ້.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>ເຖິງລຸ່ມຂອງເຂດການເຄື່ອນຍ້າຍ</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>ເຖິງຂະບົນການສຳເລັດສູງສຸດ</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>ປ້ອງກຳນົດເຂດການບັນທຶກ</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>ເຄື່ອນຍ້າຍກຳມັນ ຫຼື ຖືກຄລິກເພື່ອເອົາການບັນທຶກສະແໜ່ງ</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>ກຳລັງເຄື່ອນຍ້າຍໄລ່ໄວ</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>ጽሁፍ እዚህ ያስገቡ</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>መውጫ/ማስቀመጫ</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>መጠን ማስተካከያ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>ማሰናጃ</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>በፍጥነት ማስጀመሪያ</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>ማስቀመጫ</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>አራት ማእዘን</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>ኤሊፕስ</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>መስመር</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>እርሳስ</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>ጽሁፍ</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ማጥፊያ</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>መተው</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Help</source>
        <translation>እርዳታ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sound</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>መቅረጽ ማስጀመሪያ</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>ምርጫዎች</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>ቀስት</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>መደበር ምስል እንደገና እንደገና ማስተካከል (መልክ እንደገና ማስተካከል)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>መስል ምስል እንደገና ማስተካከል (መልክ እንደገና ማስተካከል)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>መስል ምስል እንደገና ማስተካከል (መልክ እንደገና ማስተካከል)</translation>
    </message>
</context>
<context>
    <name>StartTooltip</name>
    <message>
        <source>Click or drag to
select the area to record</source>
        <translation>ይጫኑ ወይንም ይጎትቱ ወደ
ተመረጠው ቦታ ለ መቅረጽ</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>ክ ምስል እንደገና ማስተካከል</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>ክ ምስል እንደገና ማስተካከል</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>ክ ምስል እንደገና ማስተካከል</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>ካሜራ ማስተካከል (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>ካሜራ ማስተካከል (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>ስክሪენሂፕ</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>ማሰናጃ</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>ቅንSettings (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>አቀራረብ</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>FPS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 fps</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 fps</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 fps</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 fps</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 fps</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>ሙዕድ</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>ማይክሮፎን</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>ሲสเตም ምዕድ</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>ምርጫዎች</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>መጠቆሚያ ማሳያ</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>ክሊክ ማስተካከል</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>ማስቀመጫ ወደ</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>ዴስክቶፕ</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>ቸርቸር</translation>
    </message>
    <message>
        <source>Rectangle (R)
Press and hold Shift to draw a square</source>
        <translation>መሰል (R)
Shift ለመግዛት እንደገና ማስተካከል ይህን እንደ ስแք ማስተካከል</translation>
    </message>
    <message>
        <source>Ellipse (O)
Press and hold Shift to draw a circle</source>
        <translation>አሌፕስ (O)
Shift ለመግዛት እንደገና ማስተካከል ይህን እንደ ኬርክል ማስተካከል</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>ሊን (L)
Shift ለመግዛት እንደገና ማስተካከል ይህን እንደ በርቲካል ወይም በሸንጊያል ምስል ማስተካከል</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>አራው (X)
Shift ለመግዛት እንደገና ማስተካከል ይህን እንደ በርቲካል ወይም በሸንጊያል አራው ማስተካከል</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>ፕENCIL (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>መደበር (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>ትእ (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>ስክሪሽቶ (Alt+I)</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>ትእ ለመጠቀም (Alt+O)</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>ስክሪሽቶ ለመያዝ (Alt+P)</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>መሰረዝ (Ctrl+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>መቅረጫ</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>ቁራጭ ሰሌዳ</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>ስእሎች</translation>
    </message>
    <message>
        <source>Folder</source>
        <translation>ፎልደር</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>ማስቀመጥ በመቀመጥ ለመስቀመጥ</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>መስቀመጥ በመቀመጥ ለመስቀመጥ</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>አቀራረብ</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>ቦርደር አስተዳደር</translation>
    </message>
    <message>
        <source>None</source>
        <translation>ይም</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>ფარდობითი საფარი</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>საზღვარი</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>აპარატი</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>ტექსტის გამომწერა</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>დახურვა (Esc)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>დამტკიცება (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>გამოყოფილი მონიშვნის არეა მიემაგრე %1*%2 შესაბამისად გამოსადებილ ვიდეო ეფექტს მიიღებთ</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>ეკრანზე ჩანაწერი ამჟამად არ არსებობს</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>መውጫ</translation>
    </message>
</context>
<context>
    <name>VoiceRecordProcess</name>
    <message>
        <source>New recording</source>
        <translation>ახალი ჩანაწერი</translation>
    </message>
</context>
</TS>
